#
# spec file for package libdvbpsi
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname %{name}10
Name:           libdvbpsi
Version:        1.3.3
Release:        1.18
Summary:        Library for Decoding and Generating MPEG TS and DVB PSI Tables
License:        LGPL-2.1+
Group:          Productivity/Multimedia/Video/Editors and Convertors
Url:            http://www.videolan.org/developers/libdvbpsi.html
Source:         http://download.videolan.org/%{name}/%{version}/%{name}-%{version}.tar.bz2
Source99:       baselibs.conf
BuildRequires:  pkgconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
libdvbpsi is a simple library designed for decoding and generating
MPEG TS and DVB PSI tables. Current features: * Program Association Table
(PAT), decoder and generator.

%package -n %{libname}
Summary:        Library for Decoding and Generating MPEG TS and DVB PSI Tables
Group:          System/Libraries

%description -n %{libname}
libdvbpsi is a simple library designed for decoding and generating
MPEG TS and DVB PSI tables. Current features: * Program Association Table
(PAT), decoder and generator.

%package devel
Summary:        Development headers and libraries for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
libdvbpsi is a simple library designed for decoding and generating
MPEG TS and DVB PSI tables. Current features: * Program Association Table
(PAT), decoder and generator.

%prep
%setup -q

%build
%configure\
	--disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr (-, root, root)
%{_libdir}/libdvbpsi.so.*

%files devel
%defattr (-, root, root)
%doc AUTHORS COPYING ChangeLog NEWS README
%{_libdir}/libdvbpsi.so
%{_includedir}/dvbpsi
%{_libdir}/pkgconfig/libdvbpsi.pc

%changelog
* Thu Sep 13 2018 enzokiel@kabelmail.de
- Update to version 1.3.3:
  + Fix regression in dvbpsi_decoder_psi_section_add()
    set i_last_section_number
* Mon Feb 19 2018 enzokiel@kabelmail.de
- Update to version 1.3.2:
  + Fix bug in dvbpsi_decoder_psi_section_add() set
    i_last_section_number
  + Fix bug in descriptor 0x8a that prevented it from being parsed
    properly
  + Fix bug in descriptor 0x56 generation with multiple teletext
    page entries
  + Fix bug in descriptor 0x41 correct maximum service count
* Mon Feb 20 2017 tchvatal@suse.com
- Cleanup a bit with spec-cleaner
* Sat Feb 18 2017 joerg.lorenzen@ki.tng.de
- Update to version 1.3.1:
  + Fix bugs in table: EIT
  + Fix test_dr
- Removed libdvbpsi-gcc5-fixes.patch, fixed upstream.
* Mon Jun  8 2015 joerg.lorenzen@ki.tng.de
- Update to version 1.3.0:
  + New descriptor:
  - 0x10 Smoothing Buffer
  - 0x11 STD descriptor
  - 0x12 IBP descriptor
  - 0x1b MPEG-4 video descriptor
  - 0x1c MPEG-4 audio descriptor
  + Fix bugs in descriptor: 0x02, 0x0a, 0x45, 0x48, 0x50, 0x56, 0x7c
  + Fix bugs in table: EIT, NIT
  + Fix bugs in demux.c
  + Build with mingw32
  + Generate descriptors: 0x83, 0xa1
  + Documentation fixes:
  - tables: NIT
  - descriptors: 0xa1
- Fixed libdvbpsi-gcc5-fixes.patch and changed baselibs.conf
  to libdvbpsi10.
* Thu May  7 2015 dmueller@suse.com
- add libdvbpsi-gcc5-fixes.patch: Fix build with GCC 5.x
* Fri Dec 19 2014 joerg.lorenzen@ki.tng.de
- Added baselibs.conf as source to spec file and fixed download
  url for source package.
* Thu Dec 18 2014 joerg.lorenzen@ki.tng.de
- Update to version 1.2.0:
  + Rename define  DVDPSI_GetContentCategoryFromType() to
  DVBPSI_GetContentCategoryFromType()
  - the prefix said DVD, should have been DVB instead
  + Added new descriptors:
  - 0xa1 Service location
  - 0x4c Time shifted service
  - 0x53 CA system id
  - 0x81 AC3 audio
  - 0x86 Caption service
  + Fixed Coverity Scan issues
  - out-of-bound writes
  - null pointer dereferences
  - resource leaks
  - check return values
* Sat Dec 21 2013 zaitor@opensuse.org
- Update to version 1.1.2:
  + Various bugfixes for ATSC PSI tables.
  + dvbpsi_packet_push() bugfix.
  + Various bugfixes for dvbinfo.
  + Ignore invalid program pids (pid=0) inside PAT table
    (vlc#9695).
- Changes from version 1.1.1:
  + Various bugfixes (documentation, dvbinfo).
  + Check TDT and TOT in dvbpsi_CheckPSISection() both have
    b_syntax_indicator set to '0'.
  + Allow SDT with table_id 0x46.
* Tue May  7 2013 dimstar@opensuse.org
- Update baselibs.conf accordingly to producte libdvbpsi9-32bit.
* Wed Apr 24 2013 sbrabec@suse.cz
- Upgrade to version 1.1.0:
  * New API: make API more consistent, see howto-new-api.
  * Bew SONAME.
  * Remove deprecated APIs and bump library version.
  * Corrected use of dvbpsi_ValidPSISection().
  * Remove workaround for checking CRC32 in TOT PSI table.
  * Add function dvbpsi_CalculateCRC32().
  * Fix offset for description parsing in tables.
  * Several new descriptors.
  * EIT table generation, and decoding fixes, add NVOD event
    detection.
  * new example application dvbinfo
  * misc examples: fixes to gen_pat, gen_pmt
  * updated documentation (new api howto)
  * add log callback (remove fprintf's)
  * RST table decoding and generation
  * descriptor 0x03: added variable_rate_audio_indicator
  * ATSC tables EIT, ETT, MGT, STT and VCT decoders
* Thu Nov  3 2011 pascal.bleser@opensuse.org
- use proper filenames in files section, to make the build fail if the
  SONAME changes
- update to 0.2.2:
  * revert regression introduced by "ignore initial discontinuity" commit
- changes from 0.2.1:
  * ignore initial discontinuity
* Fri May  6 2011 dimstar@opensuse.org
- Update to version 0.2.0:
  + License change of libdvbpsi from GPLv2 to LGPLv2.1
  + new CUE Identifier descriptor support (0x8a)
  + new Splice Information Section table support (0xFC) (SCTE 35
    2004)
  + new BAT table (decoder and generator)
  + new descriptor 0x44
  + depreceated all API's in preparation for 1.0.0 release with
    reworked API
- Adjust License Tags from GPLv2+ to LPGLv2.1+
- Remove Provides/Obsoletes libdvbpsi: openSUSE 10.3 is long gone.
* Sun May  1 2011 toddrme2178@gmail.com
- Added 32bit compatibility libraries
- Removed self-obsoletes (fix for RPMLINT warning)
* Fri Sep 10 2010 dimstar@opensuse.org
- Update to version 0.1.7:
  + new VBI data descriptor support (0x45)
  + NIT support
  + TOT/TDT support
  + new DVB Satellite Delivery systems descriptor support (0x43)
  + new DVB Local time offset descriptor support (0x58)
  + new Terrestrial Delivery systems descriptor support (0x5a)
- Remove autoreconf call: there is no need for it.
- Add pkg-config BuildRequires.
* Tue Jan 15 2008 sbrabec@suse.cz
- Updated to version 0.1.6:
  * fixed a parsing bug due to outdated spec in ISO 639 language
    descriptor
  * fixed the use of uninitialized data when
    section_syntax_indicator=0
  * fixed a parsing bug in the EBU teletext descriptor decoder
  * fixed the declaration of dvbpsi_DecodeTeletextDr
  * new example tool for checking an MPEG-2 TS file
  * fixed EIT discontinuities
  * new cat support
  * new PDC support descriptor 0x69
* Mon Aug 20 2007 crrodriguez@suse.de
- fix wrong .so file in non-devel package.
- remove static libraries and pointless libtool archive with empty
  dependency_libs.
* Wed Jun 28 2006 sbrabec@suse.cz
- New SuSE package, version 0.1.5.
